GetPriceHistoryRequest

Struct GetPriceHistoryRequest 

pub struct GetPriceHistoryRequest { /* private fields */ }
Get PriceHistory for a single symbol and date ranges.

Implementations

Source

impl GetPriceHistoryRequest

pub fn period_type(&mut self, val: PeriodType) -> &mut Self

The chart period being requested.

Available values : day, month, year, ytd

pub fn period(&mut self, val: i64) -> &mut Self

The number of chart period types.

If the Self::period_type is

  • day - valid values are 1, 2, 3, 4, 5, 10
  • month - valid values are 1, 2, 3, 6
  • year - valid values are 1, 2, 3, 5, 10, 15, 20
  • ytd - valid values are 1

If the Self::period is not specified and the Self::period_type is

  • day - default period is 10.
  • month - default period is 1.
  • year - default period is 1.
  • ytd - default period is 1.
pub fn frequency_type(&mut self, val: FrequencyType) -> &mut Self

The time Self::frequency_type

If the Self::period_type is

  • day - valid value is minute
  • month - valid values are daily, weekly
  • year - valid values are daily, weekly, monthly
  • ytd - valid values are daily, weekly

If Self::frequency_type is not specified, default value depends on the Self::period_type

  • day - defaulted to minute.
  • month - defaulted to weekly.
  • year - defaulted to monthly.
  • ytd - defaulted to weekly.

Available values : minute, daily, weekly, monthly

pub fn frequency(&mut self, val: i64) -> &mut Self

The time frequency duration

If the Self::frequency_type is

  • minute - valid values are 1, 5, 10, 15, 30
  • daily - valid value is 1
  • weekly - valid value is 1
  • monthly - valid value is 1

If Self::frequency is not specified, default value is 1

pub fn start_date(&mut self, val: DateTime<Utc>) -> &mut Self

If not specified Self::start_date will be (Self::end_date - Self::period) excluding weekends and holidays.

pub fn end_date(&mut self, val: DateTime<Utc>) -> &mut Self

If not specified, the Self::end_date will default to the market close of previous business day.

pub fn need_extended_hours_data(&mut self, val: bool) -> &mut Self

Need extended hours data

pub fn need_previous_close(&mut self, val: bool) -> &mut Self

Need previous close price/date

pub async fn send(self) -> Result<CandleList, Error>