QuoteResponse

Enum QuoteResponse 

pub enum QuoteResponse {
    Bond(String),
    Equity(Box<EquityResponse>),
    Forex(ForexResponse),
    Future(FutureResponse),
    FutureOption(FutureOptionResponse),
    Index(IndexResponse),
    MutualFund(MutualFundResponse),
    Option(Box<OptionResponse>),
}
a (symbol, QuoteResponse) map. SCHWis an example key

Variants

Implementations

Source

impl QuoteResponse

pub fn symbol(&self) -> &str

Returns the symbol of the quote

pub fn n52week_high(&self) -> Option<f64>

Returns the 52-week high price

pub fn n52week_low(&self) -> Option<f64>

Returns the 52-week low price

pub fn ask_price(&self) -> Option<f64>

Returns the current best ask price

pub fn ask_size(&self) -> Option<i64>

Returns the number of shares for ask

pub fn ask_time(&self) -> Option<DateTime<Utc>>

Returns the last ask time in Utc format

pub fn bid_price(&self) -> Option<f64>

Returns the current best bid price

pub fn bid_size(&self) -> Option<i64>

Returns the number of shares for bid

pub fn bid_time(&self) -> Option<DateTime<Utc>>

Returns the last bid time in Utc format

pub fn close_price(&self) -> f64

Returns the previous day’s closing price

pub fn high_price(&self) -> Option<f64>

Returns the day’s high trade price

pub fn last_price(&self) -> Option<f64>

Returns the latest traded price

pub fn last_size(&self) -> Option<i64>

Returns the number of shares traded with the last trade

pub fn low_price(&self) -> Option<f64>

Returns the day’s low trade price

pub fn net_change(&self) -> f64

Returns the current last-prev close price difference

pub fn open_price(&self) -> Option<f64>

Returns the day’s open trade price

pub fn quote_time(&self) -> Option<DateTime<Utc>>

Returns the time of the latest quote in Utc format

pub fn trade_time(&self) -> DateTime<Utc>

Returns the time of the last trade in Utc format

pub fn total_volume(&self) -> Option<u64>

Returns the total volume of trades for the day including pre/post market