Duration

Enum Duration 

pub enum Duration {
    Day,
    GoodTillCancel,
    FillOrKill,
    ImmediateOrCancel,
    EndOfWeek,
    EndOfMonth,
    NextEndOfMonth,
    Unknown,
}
Length of time over which the trade will be active.

Variants



Day

Cancel the trade at the end of the trading day. Note if the order cannot be filled all at once, you may see partial executions throughout the day.



GoodTillCancel

Keep the trade open for six months, or until the end of the cancel date, whichever is shorter. Note if the order cannot be filled all at once, you may see partial executions over the lifetime of the order.



FillOrKill

Either execute the order immediately at the specified price, or cancel it immediately.



ImmediateOrCancel



EndOfWeek



EndOfMonth



NextEndOfMonth



Unknown