pub enum QuoteResponse {
Bond(String),
Equity(Box<EquityResponse>),
Forex(ForexResponse),
Future(FutureResponse),
FutureOption(FutureOptionResponse),
Index(IndexResponse),
MutualFund(MutualFundResponse),
Option(Box<OptionResponse>),
}Expand description
a (symbol, QuoteResponse) map. SCHWis an example key
Variants
Bond(String)
Equity(Box<EquityResponse>)
Forex(ForexResponse)
Future(FutureResponse)
FutureOption(FutureOptionResponse)
Index(IndexResponse)
MutualFund(MutualFundResponse)
Option(Box<OptionResponse>)
Implementations
Sourceimpl QuoteResponse
impl QuoteResponse
Sourcepub fn n52week_high(&self) -> Option<f64>
pub fn n52week_high(&self) -> Option<f64>
Returns the 52-week high price
Sourcepub fn n52week_low(&self) -> Option<f64>
pub fn n52week_low(&self) -> Option<f64>
Returns the 52-week low price
Sourcepub fn close_price(&self) -> f64
pub fn close_price(&self) -> f64
Returns the previous day’s closing price
Sourcepub fn high_price(&self) -> Option<f64>
pub fn high_price(&self) -> Option<f64>
Returns the day’s high trade price
Sourcepub fn last_price(&self) -> Option<f64>
pub fn last_price(&self) -> Option<f64>
Returns the latest traded price
Sourcepub fn net_change(&self) -> f64
pub fn net_change(&self) -> f64
Returns the current last-prev close price difference
Sourcepub fn open_price(&self) -> Option<f64>
pub fn open_price(&self) -> Option<f64>
Returns the day’s open trade price
Sourcepub fn quote_time(&self) -> Option<DateTime<Utc>>
pub fn quote_time(&self) -> Option<DateTime<Utc>>
Returns the time of the latest quote in Utc format
Sourcepub fn trade_time(&self) -> DateTime<Utc>
pub fn trade_time(&self) -> DateTime<Utc>
Returns the time of the last trade in Utc format
Sourcepub fn total_volume(&self) -> Option<u64>
pub fn total_volume(&self) -> Option<u64>
Returns the total volume of trades for the day including pre/post market