pub struct ReferenceOption {Show 19 fields
pub contract_type: ContractType,
pub cusip: Option<String>,
pub days_to_expiration: i64,
pub deliverables: Option<String>,
pub description: String,
pub exchange: String,
pub exchange_name: String,
pub exercise_type: Option<ExerciseType>,
pub expiration_day: u8,
pub expiration_month: u8,
pub expiration_type: Option<ExpirationType>,
pub expiration_year: i64,
pub is_penny_pilot: bool,
pub last_trading_day: DateTime<Utc>,
pub multiplier: f64,
pub settlement_type: SettlementType,
pub strike_price: f64,
pub underlying: String,
pub uv_expiration_type: Option<String>,
}Expand description
Reference data of Option security
Fields
contract_type: ContractTypeIndicates call or put
cusip: Option<String>example: 0AMZN.TK12300000
CUSIP of Instrument
days_to_expiration: i64example: 94
Days to Expiration
deliverables: Option<String>example: $6024.37 cash in lieu of shares, 212 shares of AZN
Unit of trade
description: Stringexample: AMZN Aug 20 2021 2300 Put
Description of Instrument
exchange: Stringdefault: o
Exchange Code
exchange_name: StringExchange Name
exercise_type: Option<ExerciseType>option contract exercise type America or European
expiration_day: u8example: 20
maximum: 31
minimum: 1
Expiration Day
expiration_month: u8example: 8
maximum: 12
minimum: 1
Expiration Month
expiration_type: Option<ExpirationType>M for End Of Month Expiration Calendar Cycle. (To match the last business day of the month), Q for Quarterly expirations (last business day of the quarter month MAR/JUN/SEP/DEC), W for Weekly expiration (also called Friday Short Term Expirations) and S for Expires 3rd Friday of the month (also known as regular options).
expiration_year: i64example: 2021
Expiration Year
is_penny_pilot: boolexample: true
Is this contract part of the Penny Pilot program
last_trading_day: DateTime<Utc>example: 1629504000000
milliseconds since epoch
multiplier: f64example: 100
Option multiplier
settlement_type: SettlementTypeoption contract settlement type AM or PM
strike_price: f64example: 2300
Strike Price
underlying: Stringexample: AMZN Aug 20 2021 2300 Put
A company, index or fund name
uv_expiration_type: Option<String>Trait Implementations
Sourceimpl Clone for ReferenceOption
impl Clone for ReferenceOption
Sourcefn clone(&self) -> ReferenceOption
fn clone(&self) -> ReferenceOption
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more